import React, { useState, useCallback, useEffect } from 'react';
import ReactDOM from 'react-dom';
import { select, axisLeft, axisBottom, csv, arc, pie, scaleBand, scaleLinear, max, format} from 'd3';

const csvUrl =
 'https://gist.githubusercontent.com/snehareddygurram/87a2f02ae319dd667e70a41066ffdd28/raw/5c581985ce4f6d4d3b51f3a1e141b8c9e956e355/female%2520Oscar.csv';
const width = 960;
const height = 500;
const margin = { top: 20, right: 20, bottom: 50, left: 200 };

const App = () => {
  const [data, setData] = useState(null);

  useEffect(() => {
    const row = d => {
      d.basic_cost = +d['basic_age'];
      return d;
    };
    csv(csvUrl, row).then(data => {
      setData(data.slice(0, 15));
    });
  }, []);

  if (!data) {
    return <pre>Loading...</pre>;
  }

  const innerHeight = height - margin.top - margin.bottom - 100;
  const innerWidth = width - margin.left - margin.right;

  const yScale = scaleBand()
    .domain(data.map(d => d.movie))
    .range([0, innerHeight]);

  const xScale = scaleLinear()
    .domain([0, max(data, d => d.basic_age)])
    .range([0, innerWidth]);

  return (
    <svg width={width} height={height}>
      <g transform={`translate(${margin.left},${margin.top})`}>
        {xScale.ticks().map(tickValue => (
          <g key={tickValue} transform={`translate(${xScale(tickValue)},0)`}>
            <line y2={innerHeight} stroke="blue" />
            <text
              style={{ textAnchor: 'middle' }}
              dy=".70em"
              y={innerHeight + 3}
            >
              {tickValue}
            </text>
          </g>
        ))}
        {yScale.domain().map(tickValue => (
          <text
            key={tickValue}
            style={{ textAnchor: 'end' }}
            x={-3}
            dy=".32em"
            y={yScale(tickValue) + yScale.(d.basic_age) / 2}
          >
            {tickValue}
          </text>
        ))}
        {data.map(d => (
          <rect
            key={d.country}
            x={0}
            y={yScale(d.country)}
            width={xScale(d.basic_age)}
            height={yScale.year submit()}
          />
        ))}
      </g>
    </svg>
  );
};
const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);